==> nocc-1.9.5.txz: usr/local/www/nocc/lang/zh-hant.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: zh-hant.php 2624 2014-10-20 17:55:48Z siebrand $
 */
/** Traditional Chinese (中文（繁體）‎)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Breawycker
 * @author Cary Leung <cary@cary.net>
 * @author LNDDYL
 * @author Lauhenry
 * @author Liuxinyu970226
 * @author Mark85296341
 * @author Oapbtommy
 * @author Wrightbus
 */

$lang_locale = 'zh_TW.UTF-8';
$default_date_format = '%Y-%m-%d';
$no_locale_date_format = '%Y-%m-%d';
$default_time_format = '%I:%M %p';
$err_user_empty = '登入名字之位置空白';
$err_passwd_empty = '密碼之位置空白';
$alt_delete = '删除已選擇之信件';
$alt_delete_one = '删除此信件';
$alt_new_msg = '新信件';
$alt_reply = '回覆信件';
$alt_reply_all = '回覆所有人';
$alt_forward = '轉寄';
$alt_next = '下一頁';
$alt_prev = '上一頁';
$title_next_page = '下一頁';
$title_prev_page = '上一頁';
$title_next_msg = '下一封';
$title_prev_msg = '上一封';
$html_theme_label = '佈景主題：';
$html_welcome = '歡迎光臨%1$s';
$html_login = '登入';
$html_user_label = '使用者：';
$html_passwd_label = '密碼：';
$html_submit = '提交';
$html_help = '說明';
$html_server_label = '伺服器';
$html_wrong = '登入名字或密碼不正確';
$html_retry = '再嘗試';
$html_remember = '記住設定';
$html_lang_label = '語言：';
$html_preferences = '偏好設定';
$html_full_name_label = '全名：';
$html_email_address_label = '電郵位址：';
$html_hide_addresses = '隱藏地址';
$html_reply_to = '回覆';
$html_signature_label = '簽名：';
$html_send_html_mail = '以HTML格式發送電郵';
$html_folder_subscribe = '訂閱';
$html_folder_rename = '重新命名';
$html_of = '/';
$html_view_header = '顯示標題';
$html_remove_header = '不顯示標題';
$html_inbox = '信箱';
$html_new_msg = '寫信件';
$html_reply = '回覆';
$html_reply_short = '回復：';
$html_reply_all = '回覆所有人';
$html_forward = '轉寄';
$html_forward_short = 'Fwd:';
$html_delete = '刪除';
$html_new = '新';
$html_mark = '刪除';
$html_att_label = '附件：';
$html_atts_label = '附件:';
$html_unknown = '[不明]';
$html_attach = '附件';
$html_attach_forget = '你忘記加入附件 !';
$html_attach_delete = '删除已選擇的';
$html_sort_by = '排序方式';
$html_from = '由';
$html_subject = '題目';
$html_date = '日期';
$html_sent_label = '傳送';
$html_size = '體積';
$html_totalsize = '總體積';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = '位元組';
$html_filename = '檔名';
$html_to = '收件人';
$html_cc = '複製至';
$html_nosubject = '無題目';
$html_send = '傳送';
$html_cancel = '取消';
$html_no_mail = '無內容.';
$html_logout = '登出';
$html_msg = '信件';
$html_msgs = '信件';
$html_lowest = '最低';
$html_low = '低';
$html_normal = '中';
$html_high = '高';
$html_highest = '最高';
$html_flagged = '標記';
$html_spam = '垃圾郵件';
$html_spam_warning = '此消息已被列為垃圾郵件。';
$html_mark_as = '標記為';
$html_read = '已讀';
$html_unread = '未讀';
$html_encoding_label = '字元編碼：';
$html_add = '新增';
$html_back = '返回';
$html_contact_first = '名';
$html_contact_last = '姓';
$html_contact_mail = '電郵';
$html_contact_list = '%1$s的聯繫人列表';
$html_contact_del = '從聯繫人名單';
$html_contact_err2 = '您不能再加聯繫人';
$html_down_mail = '下載';
$original_msg = '-- 原始內容 --';
$to_empty = '此 \'收件人\' 之位置不能沒有 !';
$html_images_warning = '為安全計，不顯示遠程圖像。';
$html_images_display = '顯示圖片';
$html_err_file_contacts = 'Unable to open contacts file for writing.';
$html_search = '搜尋';

==> nocc-1.9.6.txz: usr/local/www/nocc/lang/zh-hant.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: zh-hant.php 2660 2016-01-27 09:35:17Z siebrand $
 */
/** Traditional Chinese (中文（繁體）‎)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Breawycker
 * @author Cary Leung <cary@cary.net>
 * @author Cwlin0416
 * @author LNDDYL
 * @author Lauhenry
 * @author Liuxinyu970226
 * @author Mark85296341
 * @author Oapbtommy
 * @author Wrightbus
 */

$lang_locale = 'zh_TW.UTF-8';
$default_date_format = '%Y-%m-%d';
$no_locale_date_format = '%Y-%m-%d';
$default_time_format = '%I:%M %p';
$err_user_empty = '登入名字之位置空白';
$err_passwd_empty = '密碼之位置空白';
$alt_delete = '删除已選擇之信件';
$alt_delete_one = '删除此信件';
$alt_new_msg = '新信件';
$alt_reply = '回覆信件';
$alt_reply_all = '回覆所有人';
$alt_forward = '轉寄';
$alt_next = '下一頁';
$alt_prev = '上一頁';
$title_next_page = '下一頁';
$title_prev_page = '上一頁';
$title_next_msg = '下一封';
$title_prev_msg = '上一封';
$html_theme_label = '主題：';
$html_welcome = '歡迎光臨%1$s';
$html_login = '登入';
$html_user_label = '使用者：';
$html_passwd_label = '密碼：';
$html_submit = '送出';
$html_help = '說明';
$html_server_label = '伺服器：';
$html_wrong = '登入名字或密碼不正確';
$html_retry = '再嘗試';
$html_remember = '記住設定';
$html_lang_label = '語言：';
$html_preferences = '偏好設定';
$html_full_name_label = '全名：';
$html_email_address_label = '電子郵件地址：';
$html_hide_addresses = '隱藏地址';
$html_reply_to = '回覆';
$html_signature_label = '簽名：';
$html_send_html_mail = '以 HTML 格式傳送電子郵件';
$html_folder_subscribe = '訂閱';
$html_folder_rename = '重新命名';
$html_of = '/';
$html_view_header = '顯示標題';
$html_remove_header = '不顯示標題';
$html_inbox = '信箱';
$html_new_msg = '寫信件';
$html_reply = '回覆';
$html_reply_short = '回復：';
$html_reply_all = '回覆所有人';
$html_forward = '轉寄';
$html_forward_short = 'Fwd:';
$html_delete = '刪除';
$html_new = '新';
$html_mark = '刪除';
$html_att_label = '附件：';
$html_atts_label = '附件:';
$html_unknown = '[不明]';
$html_attach = '附件';
$html_attach_forget = '你忘記加入附件 !';
$html_attach_delete = '删除已選擇的';
$html_sort_by = '排序方式';
$html_from = '由';
$html_subject = '題目';
$html_date = '日期';
$html_sent_label = '傳送';
$html_size = '體積';
$html_totalsize = '總體積';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = '位元組';
$html_filename = '檔名';
$html_to = '收件人';
$html_cc = '複製至';
$html_nosubject = '無題目';
$html_send = '傳送';
$html_cancel = '取消';
$html_no_mail = '無內容.';
$html_logout = '登出';
$html_msg = '信件';
$html_msgs = '信件';
$html_lowest = '最低';
$html_low = '低';
$html_normal = '中';
$html_high = '高';
$html_highest = '最高';
$html_flagged = '標記';
$html_spam = '垃圾郵件';
$html_spam_warning = '此消息已被列為垃圾郵件。';
$html_select_all = '反向選擇';
$html_mark_as = '標記為';
$html_read = '已讀';
$html_unread = '未讀';
$html_encoding_label = '字元編碼：';
$html_add = '新增';
$html_back = '返回';
$html_contact_first = '名';
$html_contact_last = '姓';
$html_contact_mail = '電郵';
$html_contact_list = '%1$s的聯繫人列表';
$html_contact_del = '從聯繫人名單';
$html_contact_err2 = '您不能再加聯繫人';
$html_contact_ruler_top = '頂部';
$html_down_mail = '下載';
$original_msg = '-- 原始內容 --';
$to_empty = '此 \'收件人\' 之位置不能沒有 !';
$html_images_warning = '為安全計，不顯示遠程圖像。';
$html_images_display = '顯示圖片';
$html_err_file_contacts = 'Unable to open contacts file for writing.';
$html_search = '搜尋';
